#!/usr/bin/env python3

import os
import psutil
import re

CPU_PATH = '/sys/devices/system/cpu'
CPU_PATTERN = re.compile('^cpu\d+$')


def cpu_total_mhz() -> int:
    """
    Calculate the "total" MHz of all CPU cores on this system
    """
    khz = 0
    try:
        # first try to get maximum frequency from "cpufreq" driver
        for entry in os.listdir(CPU_PATH):
            if CPU_PATTERN.match(entry):
                with open(os.path.join(CPU_PATH, entry, 'cpufreq', 'cpuinfo_max_freq')) as fd:
                    khz += int(fd.read().strip())
    except IOError:
        # fallback to info from cpuinfo (which would not include any scaling frequencies)
        khz = 0
        with open('/proc/cpuinfo') as fd:
            for line in fd:
                line = line.strip()
                if line:
                    k, v = line.split(':', 1)
                    if k.strip().lower() == 'cpu mhz':
                        khz += float(v.strip()) * 1000
    return int(khz // 1000)


def cpu_count() -> int:
    return psutil.cpu_count()


if __name__ == '__main__':
    print('Total MHz', cpu_total_mhz())
