#!/usr/bin/env python3

import pwd
import shlex
import subprocess
import time
from logging import getLogger

log = getLogger('pequod.agent.system-utilities')


def create_posix_user(username: str):
    try:
        pwd.getpwnam(username)
    except KeyError:
        out = execute('useradd {username}', username=username)
        if 'try again later' in out:
            time.sleep(1)
            create_posix_user(username)


def execute(cmd, _show_output=True, **kwargs):
    """
    >>> execute('true')
    ''
    """
    log.debug('Executing: %s', cmd.format(**kwargs))
    cmd = [arg.format(**kwargs) for arg in shlex.split(cmd)]
    try:
        process = subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
        output = []
        for line in process.stdout:
            line = line.decode()
            if _show_output:
                print(line, end='')
            output.append(line)
        process.wait()
        return ''.join(output)
    except subprocess.CalledProcessError as e:
        log.exception(e.output)
        raise


def get_posix_uid(username: str) -> int:
    passwd = pwd.getpwnam(username)
    return passwd.pw_uid


def reboot():
    execute('shutdown -r now')


def remove_users(users: list):
    for user_name in users:
        log.info('Deleting user %s..', user_name)
        execute('userdel {username}', username=user_name)